@@ -5,6 +5,11 @@
 #include <math.h>
 #include "asclock.h"
 
+/* prototypes */
+void enum_timezones(GtkWidget *clist );
+void location_selected(GtkWidget *list, gint row, gint column, GdkEventButton *event, gpointer data);
+
+
 GtkWidget *pic = NULL;
 
 void about_dialog(AppletWidget *applet, gpointer data)
@@ -26,7 +31,8 @@ void about_dialog(AppletWidget *applet, gpointer data)
         return;
 }
 
-GtkWidget * properties_timezone_render(GtkWidget *parent, float lat, float lon)
+static void
+properties_timezone_render(GtkWidget *parent, float lat, float lon)
 {
   GdkPixmap *pmap;
   GdkBitmap * mask;
@@ -100,12 +106,6 @@ void properties_dialog(AppletWidget *applet, gpointer data)
   gtk_window_set_title(GTK_WINDOW(&GNOME_PROPERTY_BOX(pwin)->dialog.window),
                 "AfterStep Clock Settings");
 
-  frame = gtk_vbox_new(5, TRUE);
-
-  label = gtk_label_new(_("General"));
-  gtk_widget_show(frame);
-  gnome_property_box_append_page( GNOME_PROPERTY_BOX(pwin),frame ,label);
-
   frame =  gtk_vbox_new(5, TRUE);
 
   label = gtk_label_new(_("Timezone"));
