@@ -134,7 +134,7 @@ static void update_pixmap(DriveData *dd, gint t)
 		text = _(" not mounted");
 		}
 	gtk_pixmap_set(GTK_PIXMAP(dd->button_pixmap), pixmap, NULL);
-	tiptext = g_copy_strings(dd->mount_point,text,NULL);
+	tiptext = g_strconcat(dd->mount_point,text,NULL);
 	gtk_tooltips_set_tip (dd->tooltip, dd->applet, tiptext, NULL);
 	g_free(tiptext);
 }
@@ -482,9 +482,11 @@ static GtkWidget * applet_start_new_applet(const gchar *goad_id, const char **pa
 	DriveData *dd;
 	GtkWidget *applet;
 
+	if(strcmp(goad_id, "drivemount_applet")) return NULL;
+
 	applet = applet_widget_new(goad_id);
-		if (!applet)
-			g_error("Can't create applet!\n");
+	if (!applet)
+		g_error("Can't create applet!\n");
 
 	dd = create_drive_widget(applet);
 
