@@ -564,7 +564,7 @@ static void about_cb (AppletWidget *widget, gpointer data)
 		APPLET_VERSION_MIN, APPLET_VERSION_REV);
 
 	authors[0] = _("Justin Maurer <justin@openprojects.net>");
-	authors[3] = _("Craig Small <csmall@small.dropbear.co.uk>");
+	authors[3] = _("Craig Small <csmall@eye-net.com.au>");
 	authors[1] = _("John Ellis <johne@bellatlantic.net> - Display engine");
 	authors[2] = _("Frederic Devernay <devernay@istar.fr>");
 	authors[4] = NULL;
@@ -670,16 +670,13 @@ static void applet_start_new_applet(const gchar *goad_id, gpointer data)
 int main (int argc, char *argv[])
 {
 	GtkWidget *applet;
-	GList *list;
 
 	/* Initialize the i18n stuff */
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
-	list = g_list_append(NULL,"scroll_applet");
 	applet_widget_init("scroll_applet", VERSION, argc, argv, NULL,
 			   0, NULL);
-	g_list_free(list);
 
 	applet = applet_widget_new("scroll_applet");
 	if (!applet)
