@@ -62,7 +62,7 @@ docObjFree(docObj obj)
 	g_return_if_fail( obj != NULL );
 
 	g_free(obj->ref);
-	g_free(obj->absoluteRef);
+	free(obj->absoluteRef);
 	g_free(obj->humanRef);
 	g_free(obj->mimeType);
 	
