@@ -174,7 +174,7 @@ add_drawers_from_dir(char *dirname, char *name, int pos, PanelWidget *panel)
 	char *dentry_name;
 	char *subdir_name;
 	char *pixmap_name;
-	GSList *list;
+	GSList *list, *li;
 
 	if(!g_file_exists(dirname))
 		return;
@@ -202,9 +202,8 @@ add_drawers_from_dir(char *dirname, char *name, int pos, PanelWidget *panel)
 	newpanel = PANEL_WIDGET(DRAWER_WIDGET(drawer->drawer)->panel);
 	
 	list = get_files_from_menudir(dirname);
-	while(list) {
-		char *filename = g_concat_dir_and_file(dirname,
-						       list->data);
+	for(li = list; li!= NULL; li = g_slist_next(li)) {
+		char *filename = g_concat_dir_and_file(dirname, li->data);
 		struct stat s;
 		if (stat (filename, &s) == 0) {
 			if (S_ISDIR (s.st_mode)) {
@@ -221,9 +220,9 @@ add_drawers_from_dir(char *dirname, char *name, int pos, PanelWidget *panel)
 			}
 		}
 		g_free(filename);
-		g_free(list->data);
-		list = my_g_slist_pop_first(list);
+		g_free(li->data);
 	}
+	g_slist_free(list);
 }
 
 /*add a drawer with the contents of a menu to the panel*/
@@ -328,7 +327,8 @@ edit_dentry(GtkWidget *widget, char *item_loc)
 	gtk_window_set_policy(GTK_WINDOW(dialog), FALSE, FALSE, TRUE);
 	
 	o = gnome_dentry_edit_new_notebook(GTK_NOTEBOOK(GNOME_PROPERTY_BOX(dialog)->notebook));
-	gtk_object_set_data(o,"location",dentry->location);
+	/*item loc will be alive all this time*/
+	gtk_object_set_data(o,"location",item_loc);
 
 	gnome_dentry_edit_set_dentry(GNOME_DENTRY_EDIT(o),dentry);
 
@@ -472,14 +472,16 @@ show_item_menu(GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 	if(sim->item_loc &&
 	   /*A HACK: but it works, don't have it edittable if it's redhat
 	     menus as they are auto generated!*/
-	   strstr(sim->item_loc,".gnome/apps-redhat/") &&
+	   !strstr(sim->item_loc,".gnome/apps-redhat/") &&
 	   access(sim->item_loc,W_OK)==0) {
+		puts(sim->item_loc);
 		/*file exists and is writable, we're in bussines*/
 		gtk_widget_set_sensitive(sim->prop_item,TRUE);
 	} else if(!sim->item_loc || errno==ENOENT) {
 		/*the dentry isn't there, check if we can write the
 		  directory*/
-		if(access(sim->mf->menudir,W_OK)==0)
+		if(access(sim->mf->menudir,W_OK)==0 &&
+		   !strstr(sim->mf->menudir,".gnome/apps-redhat/"))
 			gtk_widget_set_sensitive(sim->prop_item,TRUE);
 	}
 	
@@ -521,6 +523,8 @@ show_item_menu_mi_cb(GtkWidget *w, GdkEvent *event, ShowItemMenu *sim)
 static void
 destroy_item_menu(GtkWidget *w, ShowItemMenu *sim)
 {
+	/*NOTE: don't free item_loc or mf.. it's not ours and will be free'd
+	  elsewhere*/
 	if(sim->menu)
 		gtk_widget_destroy(sim->menu);
 	g_free(sim);
@@ -590,7 +594,7 @@ drag_data_get_menu_cb (GtkWidget *widget, GdkDragContext     *context,
 		       GtkSelectionData   *selection_data, guint info,
 		       guint time, char *item_loc)
 {
-	gchar *uri_list = g_copy_strings ("file:", item_loc, NULL);
+	gchar *uri_list = g_strconcat ("file:", item_loc, NULL);
 	gtk_selection_data_set (selection_data,
 				selection_data->target, 8, uri_list,
 				strlen(uri_list));
@@ -645,7 +649,8 @@ setup_title_menuitem (GtkWidget *menuitem, GtkWidget *pixmap, char *title,
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
 	if(mf) {
 		ShowItemMenu *sim = g_new0(ShowItemMenu,1);
-		sim->mf = mf;
+		sim->mf = mf;/*make sure you don't free this,
+			       it's not ours!*/
 		sim->type = 0;
 		gtk_signal_connect(GTK_OBJECT(menuitem),"event",
 				   GTK_SIGNAL_FUNC(show_item_menu_mi_cb),
@@ -716,7 +721,8 @@ setup_full_menuitem (GtkWidget *menuitem, GtkWidget *pixmap, char *title,
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
 	if(item_loc) {
 		ShowItemMenu *sim = g_new0(ShowItemMenu,1);
-		sim->item_loc = item_loc;
+		sim->item_loc = item_loc; /*make sure you don't free this,
+					    it's not ours!*/
 		sim->type = 1;
 		gtk_signal_connect(GTK_OBJECT(menuitem),"event",
 				   GTK_SIGNAL_FUNC(show_item_menu_mi_cb),
@@ -1142,8 +1148,8 @@ create_menu_at (GtkWidget *menu,
 	FileInfo *fi;
 	GSList *finfo = NULL;
 	GSList *flist = NULL;
+	GSList *li = NULL;
 	GSList *mfl = NULL;
-	char *thisfile;
 	int add_separator = FALSE;
 	int first_item = 0;
 	GtkWidget *menuitem;
@@ -1202,14 +1208,13 @@ create_menu_at (GtkWidget *menu,
 
 	flist = get_files_from_menudir(menudir);
 	
-	while (flist) {
-		GtkWidget     *sub, *pixmap;
-		char          *pixmap_name;
-		char          *menuitem_name;
+	for(li = flist; li != NULL; li = g_slist_next(li)) {
+		char *thisfile = li->data;
+		GtkWidget *sub, *pixmap;
+		char *pixmap_name;
+		char *menuitem_name;
 		
-		thisfile = flist->data;
 		filename = g_concat_dir_and_file(menudir,thisfile);
-		flist = my_g_slist_pop_first(flist);
 		
 		if (stat (filename, &s) == -1) {
 			g_warning("Something is wrong, "
@@ -1323,6 +1328,7 @@ create_menu_at (GtkWidget *menu,
 		g_free(filename);
 		g_free(thisfile);
 	}
+	g_slist_free(flist);
 	
 	mf = g_new(MenuFinfo,1);
 	mf->menudir = g_strdup(menudir);
@@ -2015,22 +2021,30 @@ free_rh_item(RHMenuItem *rh)
 static char *
 read_word(char **p)
 {
-	static char buf[256] = "";
+	char *buf;
 	char *w;
-	int quoted = FALSE;
+	int quoted;
+	int len;
 	if(!p) return NULL;
 	if(!*p) return NULL;
 	while(*(*p) == ' ' || *(*p) == '\t') (*p)++;
 	if(!(*(*p))) return NULL;
+	quoted = FALSE;
+	for(w=*p,len=0;
+	    *w && (quoted || (*w!=' ' && *w!='\t'));
+	    w++) {
+		if(*w=='"')
+			quoted = !quoted;
+		else
+			len++;
+	}
+	buf = g_malloc(len+1);
+	quoted = FALSE;
 	for(w=buf;*(*p) && (quoted || (*(*p)!=' ' && *(*p)!='\t'));(*p)++) {
 		if(*(*p)=='"')
 			quoted = !quoted;
 		else {
-			*w = *(*p);
-			if((w++)-buf >= 255) {
-				*w='\0';
-				return buf;
-			}
+			*w++ = *(*p);
 		}
 	}
 	*w='\0';
@@ -2091,62 +2105,70 @@ add_redhat_entry(GSList *list, char *file)
 		p = strchr(buf,'\n');
 		if(p) *p='\0';
 		p = buf;
-		read_word(&p); /*XXX:ignore??*/
+		g_free(read_word(&p)); /*XXX:ignore??*/
 		w = read_word(&p);
 		if(strcmp(w,"name")==0) {
 			g_free(rh->name);
-			rh->name = g_strdup(read_word(&p));
+			rh->name = read_word(&p);
 		} else if(strcmp(w,"description")==0) {
 			g_free(rh->u.item.description);
-			rh->u.item.description = g_strdup(read_word(&p));
+			rh->u.item.description = read_word(&p);
 		} else if(strcmp(w,"icon")==0) {
-			w = read_word(&p);
+			char *s = read_word(&p);
 			g_free(rh->u.item.icon);
-			if(*w == '/') {
-				if(g_file_exists(w))
-					rh->u.item.icon = g_strdup(w);
-				else
+			if(*s == '/') {
+				if(g_file_exists(s))
+					rh->u.item.icon = s;
+				else {
+					g_free(s);
 					rh->u.item.icon = NULL;
+				}
 			} else {
-				rh->u.item.icon = g_concat_dir_and_file("/usr/share/icons", w);
+				rh->u.item.icon = g_concat_dir_and_file("/usr/share/icons", s);
 				if(!g_file_exists(rh->u.item.icon)) {
 					g_free(rh->u.item.icon);
-					rh->u.item.icon = gnome_pixmap_file(w);
+					rh->u.item.icon = gnome_pixmap_file(s);
 				}
+				g_free(s);
 			}
 		} else if(strcmp(w,"mini-icon")==0) {
-			w = read_word(&p);
+			char *s = read_word(&p);
 			g_free(rh->u.item.mini_icon);
-			if(*w == '/') {
-				if(g_file_exists(w))
-					rh->u.item.mini_icon = g_strdup(w);
-				else
+			if(*s == '/') {
+				if(g_file_exists(s))
+					rh->u.item.mini_icon = s;
+				else {
+					g_free(s);
 					rh->u.item.mini_icon = NULL;
+				}
 			} else {
-				rh->u.item.mini_icon = g_concat_dir_and_file("/usr/share/icons/mini", w);
+				rh->u.item.mini_icon = g_concat_dir_and_file("/usr/share/icons/mini", s);
 				if(!g_file_exists(rh->u.item.mini_icon)) {
 					g_free(rh->u.item.mini_icon);
-					rh->u.item.mini_icon = gnome_pixmap_file(w);
+					rh->u.item.mini_icon = gnome_pixmap_file(s);
 				}
+				g_free(s);
 			}
 		} else if(strcmp(w,"exec")==0) {
 			g_free(rh->u.item.exec);
-			rh->u.item.exec = g_strdup(read_word(&p));
+			rh->u.item.exec = read_word(&p);
 		} else if(strcmp(w,"group")==0) {
 			char *sc;
-			w = read_word(&p);
+			char *s = read_word(&p);
 
 			if(group) {
 				g_slist_foreach(group,(GFunc)g_free,NULL);
 				g_slist_free(group);
 				group = NULL;
 			}
-			sc = strtok(w,"/");
+			sc = strtok(s,"/");
 			while(sc) {
 				group = g_slist_append(group, g_strdup(sc));
 				sc = strtok(NULL,"/");
 			}
+			g_free(s);
 		}
+		g_free(w);
 	}
 	fclose(fp);
 	if(!rh->name || !rh->u.item.exec) {
@@ -2204,7 +2226,7 @@ make_rh_submenu(char *dir, GSList *rhlist)
 						 &dentry->exec_length,
 						 &dentry->exec);
 			dentry->location = g_concat_dir_and_file(dir,s);
-			if(fp) fprintf(fp,"%s\n",g_basename(dentry->location));
+			if(fp) fprintf(fp,"%s\n",s);
 			g_free(s);
 		}
 		gnome_desktop_entry_save(dentry);
