@@ -23,17 +23,17 @@
 			   GDK_POINTER_MOTION_HINT_MASK)
 
 /*list of all panel widgets created*/
-GList *panel_list = NULL;
+GSList *panel_list = NULL;
 
-/*the timeout handeler for panel dragging id,
-  yes I am too lazy to get the events to work*/
-static int panel_dragged = 0;
+static int panel_dragged = FALSE;
+static int panel_dragged_timeout = -1;
+static int panel_been_moved = FALSE;
 
 /*the number of base panels out there, never let it go below 1*/
 int base_panels = 0;
 
 extern int config_sync_timeout;
-extern GList *applets_to_sync;
+extern GSList *applets_to_sync;
 extern int panels_to_sync;
 extern int globals_to_sync;
 extern int need_complete_save;
@@ -480,9 +480,16 @@ static int
 panel_applet_added_idle(gpointer data)
 {
 	AppletInfo *info = data;
-	PanelWidget *panel = PANEL_WIDGET(info->widget->parent);
+	PanelWidget *panel;
+	
+	g_return_val_if_fail(info,FALSE);
+	g_return_val_if_fail(info->widget,TRUE);
+	g_return_val_if_fail(info->widget->parent,TRUE);
+
+	panel = PANEL_WIDGET(info->widget->parent);
 
 	orientation_change(info,panel);
+	back_change(info,panel);
 
 	return FALSE;
 }
@@ -519,8 +526,8 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	gtk_idle_add(panel_applet_added_idle,info);
 
 	/*we will need to save this applet's config now*/
-	if(g_list_find(applets_to_sync, info)==NULL)
-		applets_to_sync = g_list_prepend(applets_to_sync,info);
+	if(g_slist_find(applets_to_sync, info)==NULL)
+		applets_to_sync = g_slist_prepend(applets_to_sync,info);
 }
 
 static void
@@ -555,15 +562,16 @@ panel_applet_removed(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	}
 
 	/*we will need to save this applet's config now*/
-	if(g_list_find(applets_to_sync, info)==NULL)
-		applets_to_sync = g_list_prepend(applets_to_sync,info);
+	if(g_slist_find(applets_to_sync, info)==NULL)
+		applets_to_sync = g_slist_prepend(applets_to_sync,info);
 }
 
 static void
-menu_deactivate(GtkWidget *w, GtkWidget *panel)
+menu_deactivate(GtkWidget *w, PanelData *pd)
 {
-	if(IS_SNAPPED_WIDGET(panel))
-		SNAPPED_WIDGET(panel)->autohide_inhibit = FALSE;
+	pd->menu_age = 0;
+	if(IS_SNAPPED_WIDGET(pd->panel))
+		SNAPPED_WIDGET(pd->panel)->autohide_inhibit = FALSE;
 }
 
 static void
@@ -654,30 +662,34 @@ corner_panel_move(CornerWidget *corner, double x, double y)
 		corner_widget_change_pos_orient(corner, newloc, neworient);
 }
 
-static int
-snapped_panel_move_timeout(gpointer data)
+static void
+move_panel_to_cursor(GtkWidget *w)
 {
 	int x,y;
-
 	gdk_window_get_pointer(NULL,&x,&y,NULL);
-	snapped_panel_move(data,x,y);
-	return TRUE;
-}
-static int
-corner_panel_move_timeout(gpointer data)
-{
-	int x,y;
 
-	gdk_window_get_pointer(NULL,&x,&y,NULL);
-	corner_panel_move(data,x,y);
-	return TRUE;
+	if(IS_SNAPPED_WIDGET(w))
+		snapped_panel_move(SNAPPED_WIDGET(w),x,y);
+	else
+		corner_panel_move(CORNER_WIDGET(w),x,y);
 }
 
 static int
+panel_move_timeout(gpointer data)
+{
+	if(panel_dragged && panel_been_moved)
+		move_panel_to_cursor(data);
+	
+	panel_been_moved = FALSE;
+	panel_dragged_timeout = -1;
+
+	return FALSE;
+}
+
+static void
 panel_destroy(GtkWidget *widget, gpointer data)
 {
 	PanelData *pd = gtk_object_get_user_data(GTK_OBJECT(widget));
-	GtkWidget *panel_menu = data;
 
 	kill_config_dialog(widget);
 
@@ -696,13 +708,11 @@ panel_destroy(GtkWidget *widget, gpointer data)
 		base_panels--;
 	}
 
-	if(panel_menu)
-		gtk_widget_unref(panel_menu);
+	if(pd->menu)
+		gtk_widget_destroy(pd->menu);
 	
-	panel_list = g_list_remove(panel_list,pd);
+	panel_list = g_slist_remove(panel_list,pd);
 	g_free(pd);
-	
-	return FALSE;
 }
 
 static void
@@ -711,12 +721,24 @@ panel_applet_move(GtkWidget *panel,GtkWidget *widget, gpointer data)
 	AppletInfo *info = gtk_object_get_data(GTK_OBJECT(widget),
 					       "applet_info");
 	
-	if(g_list_find(applets_to_sync, info)==NULL)
-		applets_to_sync = g_list_prepend(applets_to_sync,info);
+	if(g_slist_find(applets_to_sync, info)==NULL)
+		applets_to_sync = g_slist_prepend(applets_to_sync,info);
+}
+
+static GtkWidget *
+panel_menu_get(PanelData *pd)
+{
+	if(pd->menu)
+		return pd->menu;
+
+	pd->menu = create_panel_root_menu(pd->panel);
+	gtk_signal_connect(GTK_OBJECT(pd->menu), "deactivate",
+			   GTK_SIGNAL_FUNC(menu_deactivate),pd);
+	return pd->menu;
 }
 
 static int
-panel_event(GtkWidget *widget, GdkEvent *event, gpointer data)
+panel_event(GtkWidget *widget, GdkEvent *event, PanelData *pd)
 {
 	GdkEventButton *bevent;
 	switch (event->type) {
@@ -724,10 +746,10 @@ panel_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 		bevent = (GdkEventButton *) event;
 		switch(bevent->button) {
 		case 3: /* fall through */
-		case 1:
 			if(!panel_applet_in_drag) {
+				GtkWidget *panel_menu = panel_menu_get(pd);
 				GtkWidget *rem = 
-					gtk_object_get_data(GTK_OBJECT(widget),
+					gtk_object_get_data(GTK_OBJECT(panel_menu),
 							    "remove_item");
 				if(IS_SNAPPED_WIDGET(widget)) {
 					SnappedWidget *snapped =
@@ -760,7 +782,8 @@ panel_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 				} else
 					gtk_widget_set_sensitive(rem,
 								 TRUE);
-				gtk_menu_popup(GTK_MENU(data), NULL, NULL,
+				pd->menu_age = 0;
+				gtk_menu_popup(GTK_MENU(panel_menu), NULL, NULL,
 					       panel_menu_position,
 					       widget, bevent->button,
 					       bevent->time);
@@ -781,21 +804,13 @@ panel_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 						  cursor,
 						  bevent->time);
 				gdk_cursor_destroy (cursor);
-				if(IS_SNAPPED_WIDGET(widget)) {
+				if(IS_SNAPPED_WIDGET(widget))
 					SNAPPED_WIDGET(widget)->autohide_inhibit = TRUE;
-					panel_dragged =
-						gtk_timeout_add(30,
-								snapped_panel_move_timeout,
-								widget);
-				} else { /*CORNER_WIDGET*/
-					panel_dragged =
-						gtk_timeout_add(30,
-								corner_panel_move_timeout,
-								widget);
-				}
+				panel_dragged = TRUE;
 				return TRUE;
 			}
 			break;
+		default: break;
 		}
 		break;
 
@@ -812,12 +827,23 @@ panel_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 					   bevent->x_root, bevent->y_root);
 			gdk_pointer_ungrab(bevent->time);
 			gtk_grab_remove(widget);
-			gtk_timeout_remove(panel_dragged);
-			panel_dragged = 0;
+			panel_dragged = FALSE;
+			panel_dragged_timeout = -1;
+			panel_been_moved = FALSE;
 			return TRUE;
 		}
 
 		break;
+	case GDK_MOTION_NOTIFY:
+		if (panel_dragged) {
+			if(panel_dragged_timeout==-1) {
+				panel_been_moved = FALSE;
+				move_panel_to_cursor(widget);
+				panel_dragged_timeout = gtk_timeout_add (30,panel_move_timeout,widget);
+			} else
+				panel_been_moved = TRUE;
+		}
+		break;
 
 	default:
 		break;
@@ -834,6 +860,7 @@ panel_sub_event_handler(GtkWidget *widget, GdkEvent *event, gpointer data)
 		/*pass these to the parent!*/
 		case GDK_BUTTON_PRESS:
 	        case GDK_BUTTON_RELEASE:
+	        case GDK_MOTION_NOTIFY:
 			bevent = (GdkEventButton *) event;
 			/*if the widget is a button we want to keep the
 			  button 1 events*/
@@ -900,10 +927,14 @@ panel_widget_dnd_drop_internal (GtkWidget *widget,
 		  else if(mimetype
 			  && !strcmp(mimetype, "application/x-gnome-app-info"))
 		    load_launcher_applet(ltmp->data, panel, pos);
-		  else if(S_ISDIR(s.st_mode))
-		    load_menu_applet(ltmp->data, MAIN_MENU_BOTH,
-				     panel, pos);
-		  else if(S_IEXEC & s.st_mode) /*executable?*/
+		  else if(S_ISDIR(s.st_mode)) {
+			  int flags = MAIN_MENU_SYSTEM|MAIN_MENU_USER;
+
+			  /*guess redhat menus*/
+			  if(g_file_exists("/etc/X11/wmconfig"))
+				  flags |= MAIN_MENU_REDHAT|MAIN_MENU_REDHAT_SUB;
+		    load_menu_applet(ltmp->data, flags, panel, pos);
+		  } else if(S_IEXEC & s.st_mode) /*executable?*/
 		    ask_about_launcher(ltmp->data,panel,pos);
 		}
 		
@@ -926,7 +957,12 @@ panel_widget_dnd_drop_internal (GtkWidget *widget,
 	}
 	case TARGET_DIRECTORY: {
 		int pos = panel_widget_get_cursorloc(panel);
-		load_menu_applet ((char *)selection_data->data, 0,
+		int flags = MAIN_MENU_SYSTEM|MAIN_MENU_USER;
+
+		/*guess redhat menus*/
+		if(g_file_exists("/etc/X11/wmconfig"))
+			flags |= MAIN_MENU_REDHAT|MAIN_MENU_REDHAT_SUB;
+		load_menu_applet ((char *)selection_data->data,flags,
 				  panel, pos);
 		break;
 	}
@@ -972,13 +1008,15 @@ panel_widget_setup(PanelWidget *panel)
 			   GDK_ACTION_COPY);
 }
 
+
 void
 panel_setup(GtkWidget *panelw)
 {
-	GtkWidget *panel_menu;
 	PanelData *pd;
 	
 	pd = g_new(PanelData,1);
+	pd->menu = NULL;
+	pd->menu_age = 0;
 	pd->panel = panelw;
 	if(IS_DRAWER_WIDGET(panelw))
 		pd->type = DRAWER_PANEL;
@@ -990,12 +1028,10 @@ panel_setup(GtkWidget *panelw)
 		g_warning("unknown panel type");
 	}
 	
-	panel_list = g_list_append(panel_list,pd);
+	panel_list = g_slist_append(panel_list,pd);
 	
 	gtk_object_set_user_data(GTK_OBJECT(panelw),pd);
 
-	panel_menu = create_panel_root_menu(panelw);
-
 	if(IS_DRAWER_WIDGET(panelw)) {
 		PanelWidget *panel = PANEL_WIDGET(DRAWER_WIDGET(panelw)->panel);
 		DrawerWidget *drawer = DRAWER_WIDGET(panelw);
@@ -1043,12 +1079,10 @@ panel_setup(GtkWidget *panelw)
 		SnappedWidget *snapped = SNAPPED_WIDGET(panelw);
 		snapped_widget_disable_buttons(snapped);
 		panel_widget_setup(panel);
-		gtk_signal_connect(GTK_OBJECT(panelw),
-				   "pos_change",
+		gtk_signal_connect(GTK_OBJECT(panelw), "pos_change",
 				   GTK_SIGNAL_FUNC(snapped_pos_change),
 				   NULL);
-		gtk_signal_connect(GTK_OBJECT(panelw),
-				   "state_change",
+		gtk_signal_connect(GTK_OBJECT(panelw), "state_change",
 				   GTK_SIGNAL_FUNC(snapped_state_change),
 				   NULL);
 		gtk_signal_connect(GTK_OBJECT(snapped->hidebutton_e), "event",
@@ -1072,16 +1106,13 @@ panel_setup(GtkWidget *panelw)
 		CornerWidget *corner = CORNER_WIDGET(panelw);
 		corner_widget_disable_buttons(corner);
 		panel_widget_setup(panel);
-		gtk_signal_connect(GTK_OBJECT(panel),
-				   "orient_change",
+		gtk_signal_connect(GTK_OBJECT(panel), "orient_change",
 				   GTK_SIGNAL_FUNC(panel_orient_change),
 				   NULL);
-		gtk_signal_connect(GTK_OBJECT(panelw),
-				   "pos_change",
+		gtk_signal_connect(GTK_OBJECT(panelw), "pos_change",
 				   GTK_SIGNAL_FUNC(corner_pos_change),
 				   NULL);
-		gtk_signal_connect(GTK_OBJECT(panelw),
-				   "state_change",
+		gtk_signal_connect(GTK_OBJECT(panelw), "state_change",
 				   GTK_SIGNAL_FUNC(corner_state_change),
 				   NULL);
 		gtk_signal_connect(GTK_OBJECT(corner->hidebutton_e), "event",
@@ -1101,30 +1132,19 @@ panel_setup(GtkWidget *panelw)
 		base_panels++;
 	} else
 		g_warning("unknown panel type");
-	gtk_signal_connect(GTK_OBJECT(panelw),
-			   "event",
-			   GTK_SIGNAL_FUNC(panel_event),
-			   panel_menu);
+	gtk_signal_connect(GTK_OBJECT(panelw), "event",
+			   GTK_SIGNAL_FUNC(panel_event),pd);
 	
 	gtk_widget_set_events(panelw,
 			      gtk_widget_get_events(panelw) |
 			      PANEL_EVENT_MASK);
 
-	gtk_signal_connect(GTK_OBJECT(panelw),
-			   "size_allocate",
-			   GTK_SIGNAL_FUNC(panel_size_allocate),
-			   NULL);
-	gtk_signal_connect(GTK_OBJECT(panelw),
-			   "destroy",
-			   GTK_SIGNAL_FUNC(panel_destroy),
-			   panel_menu);
+	gtk_signal_connect(GTK_OBJECT(panelw), "size_allocate",
+			   GTK_SIGNAL_FUNC(panel_size_allocate), NULL);
+	gtk_signal_connect(GTK_OBJECT(panelw), "destroy",
+			   GTK_SIGNAL_FUNC(panel_destroy),NULL);
 
 
-	gtk_signal_connect(GTK_OBJECT(panel_menu),
-			   "deactivate",
-			   GTK_SIGNAL_FUNC(menu_deactivate),
-			   panelw);
-
 	if(GTK_WIDGET_REALIZED(GTK_WIDGET(panelw)))
 		panel_realize(GTK_WIDGET(panelw),NULL);
 	else
@@ -1137,8 +1157,8 @@ panel_setup(GtkWidget *panelw)
 void
 send_state_change(void)
 {
-	GList *list;
-	for(list = panel_list; list != NULL; list = g_list_next(list)) {
+	GSList *list;
+	for(list = panel_list; list != NULL; list = g_slist_next(list)) {
 		PanelData *pd = list->data;
 		if(IS_SNAPPED_WIDGET(pd->panel))
 			snapped_state_change(pd->panel,
@@ -1155,13 +1175,13 @@ send_state_change(void)
 void
 destroy_all_panels(void)
 {
-	GList *list = panel_list;
+	GSList *list = panel_list;
 	while (list) {
 		PanelData *pd = list->data;
-		GList *tmp = list->next;
+		GSList *tmp = list->next;
 		gtk_widget_destroy (pd->panel);
 		list = tmp;
 	}
-	g_list_free (panel_list);
+	g_slist_free (panel_list);
 	panel_list = NULL;
 }
