@@ -29,6 +29,12 @@ Author:  Ralph Mor, X Consortium
 
 #include "smproxy.h"
 
+/* This is probably nonportable.  But then so is the call to
+   XmuClientWindow below.  */
+#include <X11/Xmu/WinUtil.h>
+
+#include <unistd.h>
+
 XtAppContext appContext;
 Display *disp;
 
@@ -58,9 +64,13 @@ Bool sent_save_done = 0;
 int Argc;
 char **Argv;
 
+
+
+static Bool LookupWindow (Window window, WinInfo **ptr_ret,
+			  WinInfo **prev_ptr_ret);
 
 
-Bool
+static Bool
 HasSaveYourself (window)
 
 Window window;
@@ -91,7 +101,7 @@ Window window;
 
 
 
-Bool
+static Bool
 HasXSMPsupport (window)
 
 Window window;
@@ -114,7 +124,7 @@ Window window;
 
 
 
-WinInfo *
+static WinInfo *
 GetClientLeader (winptr)
 
 WinInfo *winptr;
@@ -166,7 +176,7 @@ WinInfo *winptr;
 
 
 
-char *
+static char *
 CheckFullyQuantifiedName (name, newstring)
 
 char *name;
@@ -215,7 +225,7 @@ int *newstring;
 
 
 
-void FinishSaveYourself (winInfo, has_WM_SAVEYOURSELF)
+static void FinishSaveYourself (winInfo, has_WM_SAVEYOURSELF)
 
 WinInfo *winInfo;
 Bool has_WM_SAVEYOURSELF;
@@ -310,7 +320,7 @@ Bool has_WM_SAVEYOURSELF;
 
 
 
-void
+static void
 SaveYourselfCB (smcConn, clientData, saveType, shutdown, interactStyle, fast)
 
 SmcConn smcConn;
@@ -348,7 +358,7 @@ Bool fast;
 
 	    if (debug)
 	    {
-		printf ("Sent SAVE YOURSELF to 0x%x\n", winInfo->window);    
+		printf ("Sent SAVE YOURSELF to 0x%x\n", (unsigned int) winInfo->window);
 		printf ("\n");
 	    }
 	}
@@ -357,7 +367,7 @@ Bool fast;
 	    if (debug)
 	    {
 		printf ("Failed to send SAVE YOURSELF to 0x%x\n",
-		    winInfo->window);    
+		    (unsigned int) winInfo->window);
 		printf ("\n");
 	    }
 	}
@@ -366,7 +376,7 @@ Bool fast;
 
 
 
-void
+static void
 DieCB (smcConn, clientData)
 
 SmcConn smcConn;
@@ -382,7 +392,7 @@ SmPointer clientData;
     /* Now tell the client to die */
 
     if (debug)
-	printf ("Trying to kill 0x%x\n", winInfo->window);
+	printf ("Trying to kill 0x%x\n", (unsigned int) winInfo->window);
 
     XSync (disp, 0);
     XKillClient (disp, winInfo->window);
@@ -404,7 +414,7 @@ SmPointer clientData;
 
 
 
-void
+static void
 SaveCompleteCB (smcConn, clientData)
 
 SmcConn smcConn;
@@ -418,7 +428,7 @@ SmPointer clientData;
 
 
 
-void
+static void
 ShutdownCancelledCB (smcConn, clientData)
 
 SmcConn smcConn;
@@ -434,7 +444,7 @@ SmPointer clientData;
 
 
 
-void
+static void
 ProcessIceMsgProc (client_data, source, id)
 
 XtPointer	client_data;
@@ -449,7 +459,7 @@ XtInputId	*id;
 
 
 
-void
+static void
 NullIceErrorHandler (iceConn, swap,
     offendingMinorOpcode, offendingSequence, errorClass, severity, values)
 
@@ -466,7 +476,7 @@ IcePointer	values;
 }
 
 
-void
+static void
 ConnectClientToSM (winInfo)
 
 WinInfo *winInfo;
@@ -530,7 +540,7 @@ WinInfo *winInfo;
 
     if (debug)
     {
-	printf ("Connected to SM, window = 0x%x\n", winInfo->window);
+	printf ("Connected to SM, window = 0x%x\n", (unsigned int) winInfo->window);
 	printf ("\n");
     }
 
@@ -539,7 +549,7 @@ WinInfo *winInfo;
 
 
 
-int
+static int
 MyErrorHandler (display, event)
 
 Display *display;
@@ -547,6 +557,8 @@ XErrorEvent *event;
 
 {
     caught_error = 1;
+    /* Placate compiler.  */
+    return 0;
 }
 
 
@@ -589,7 +601,7 @@ WinInfo **prev_ptr_ret;
 
 
 
-WinInfo *
+static WinInfo *
 AddNewWindow (window)
 
 Window window;
@@ -628,7 +640,7 @@ Window window;
 
 
 
-void
+static void
 RemoveWindow (winptr)
 
 WinInfo *winptr;
@@ -667,7 +679,7 @@ WinInfo *winptr;
 
 
 
-void
+static void
 Got_WM_STATE (winptr)
 
 WinInfo *winptr;
@@ -764,7 +776,7 @@ WinInfo *winptr;
 
 
 
-void
+static void
 HandleCreate (event)
 
 XCreateWindowEvent *event;
@@ -849,7 +861,7 @@ XCreateWindowEvent *event;
 
 
 
-void
+static void
 HandleDestroy (event)
 
 XDestroyWindowEvent *event;
@@ -868,7 +880,7 @@ XDestroyWindowEvent *event;
 
 	if (debug)
 	{
-	    printf ("Removed window (window = 0x%x)\n", winptr->window);
+	    printf ("Removed window (window = 0x%x)\n", (unsigned int) winptr->window);
 	    printf ("\n");
 	}
 
@@ -878,7 +890,7 @@ XDestroyWindowEvent *event;
 
 
 
-void
+static void
 HandleUpdate (event)
 
 XPropertyEvent *event;
@@ -916,7 +928,7 @@ XPropertyEvent *event;
 
 
 
-void
+static void
 ProxySaveYourselfPhase2CB (smcConn, clientData)
 
 SmcConn smcConn;
@@ -929,7 +941,6 @@ SmPointer clientData;
     SmPropValue prop1val, prop2val, prop3val;
     char discardCommand[80];
     int numVals, i;
-    WinInfo *winptr;
     static int first_time = 1;
 
     if (first_time)
@@ -1016,14 +1027,23 @@ SmPointer clientData;
 
     prop1.num_vals = numVals;
 
-
-    sprintf (discardCommand, "rm %s", filename);
     prop2.name = SmDiscardCommand;
-    prop2.type = SmARRAY8;
-    prop2.num_vals = 1;
-    prop2.vals = &prop2val;
-    prop2val.value = (SmPointer) discardCommand;
-    prop2val.length = strlen (discardCommand);
+    prop2.type = SmLISTofARRAY8;
+    prop2.vals = (SmPropValue *) malloc (2 * sizeof (SmPropValue));
+
+    if (!prop2.vals)
+    {
+	success = False;
+	goto finishUp;
+    }
+
+    prop2.vals[0].value = (SmPointer) "rm";
+    prop2.vals[0].length = 2;
+
+    prop2.vals[1].value = (SmPointer) filename;
+    prop2.vals[1].length = strlen (filename);
+
+    prop2.num_vals = 2;
 
     props[0] = &prop1;
     props[1] = &prop2;
@@ -1042,7 +1062,7 @@ SmPointer clientData;
 
 
 
-void
+static void
 ProxySaveYourselfCB (smcConn, clientData, saveType,
     shutdown, interactStyle, fast)
 
@@ -1072,7 +1092,7 @@ Bool fast;
 
 
 
-void
+static void
 ProxyDieCB (smcConn, clientData)
 
 SmcConn smcConn;
@@ -1090,7 +1110,7 @@ SmPointer clientData;
 
 
 
-void
+static void
 ProxySaveCompleteCB (smcConn, clientData)
 
 SmcConn smcConn;
@@ -1102,7 +1122,7 @@ SmPointer clientData;
 
 
 
-void
+static void
 ProxyShutdownCancelledCB (smcConn, clientData)
 
 SmcConn smcConn;
@@ -1118,7 +1138,7 @@ SmPointer clientData;
 
 
 
-Status
+static Status
 ConnectProxyToSM (previous_id)
 
 char *previous_id;
@@ -1172,7 +1192,7 @@ char *previous_id;
 
 
 
-void
+static void
 CheckForExistingWindows (root)
 
 Window root;
@@ -1214,6 +1234,7 @@ Window root;
 
 
 
+int
 main (argc, argv)
 
 int argc;
@@ -1314,4 +1335,6 @@ char **argv;
 	    break;
 	}
     }
+
+    return 0;
 }
